Index: trunk/CHANGELOG
===================================================================
--- trunk/CHANGELOG	(revision 998)
+++ trunk/CHANGELOG	(revision 999)
@@ -11,15 +11,17 @@
 ! = Update/Change
 
 ------------------------------------- 2.8.0 -------------------------------------
+19-June-2009 Matthias Gallas
+#	Fixed bug that parent pages didn't inherit language settings to kind pages
 17-June-2009 Ruud Eisinga
-# Bugfix in "droplets/upgrade.php" - wrong parameter order for adding fields.
+#	Bugfix in "droplets/upgrade.php" - wrong parameter order for adding fields.
 	also the query for "normal" upgrades had a typo.
-! Added warning in output_filter that the function will be removed in 2.9
+! 	Added warning in output_filter that the function will be removed in 2.9
 17-June-2009 Dietrich Roland Pehlke
-# Bugfix in "droplets/upgrade.php" - wrong tablename change to the correct one
-+ Add upgrade-script to droplets
-! Changes on upgrade-script to avoid droping droplet-modul-tables if the exists.
-! calling "upgrate.php" or "install.php" instead of hard-coded lines to avoid
+#	Bugfix in "droplets/upgrade.php" - wrong tablename change to the correct one
++	Add upgrade-script to droplets
+!	Changes on upgrade-script to avoid droping droplet-modul-tables if the exists.
+!	calling "upgrate.php" or "install.php" instead of hard-coded lines to avoid
 	future conflicts by upgrading the modul
 15-June-2009 Matthias Gallas
 +	Added install routine for droplets to the upgrade script
Index: trunk/wb/admin/pages/add.php
===================================================================
--- trunk/wb/admin/pages/add.php	(revision 998)
+++ trunk/wb/admin/pages/add.php	(revision 999)
@@ -117,13 +117,15 @@
 // Get new order
 $position = $order->get_new($parent);
 
-// Work-out if the page parent (if selected) has a seperate template to the default
-$query_parent = $database->query("SELECT template FROM ".TABLE_PREFIX."pages WHERE page_id = '$parent'");
+// Work-out if the page parent (if selected) has a seperate template or language to the default
+$query_parent = $database->query("SELECT template, language FROM ".TABLE_PREFIX."pages WHERE page_id = '$parent'");
 if($query_parent->numRows() > 0) {
 	$fetch_parent = $query_parent->fetchRow();
 	$template = $fetch_parent['template'];
+    $language = $fetch_parent['language'];
 } else {
 	$template = '';
+    $language = DEFAULT_LANGUAGE;
 }
 
 // Insert page into pages table
